<?php
/**
 * Event Section options
 *
 * @package Theme Palace
 * @subpackage Blog Diary Pro
 * @since Blog Diary Pro 1.0.0
 */

// Add Event section
$wp_customize->add_section( 'blog_diary_pro_event_section', array(
	'title'             => esc_html__( 'Event','blog-diary-pro' ),
	'description'       => esc_html__( 'Event Section options.', 'blog-diary-pro' ),
	'panel'             => 'blog_diary_pro_front_page_panel',
) );

// Event content enable control and setting
$wp_customize->add_setting( 'blog_diary_pro_theme_options[event_section_enable]', array(
	'default'			=> 	$options['event_section_enable'],
	'sanitize_callback' => 'blog_diary_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Blog_Diary_Pro_Switch_Control( $wp_customize, 'blog_diary_pro_theme_options[event_section_enable]', array(
	'label'             => esc_html__( 'Event Section Enable', 'blog-diary-pro' ),
	'section'           => 'blog_diary_pro_event_section',
	'on_off_label' 		=> blog_diary_pro_switch_options(),
) ) );

// event title setting and control
$wp_customize->add_setting( 'blog_diary_pro_theme_options[event_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['event_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'blog_diary_pro_theme_options[event_title]', array(
	'label'           	=> esc_html__( 'Title', 'blog-diary-pro' ),
	'section'        	=> 'blog_diary_pro_event_section',
	'active_callback' 	=> 'blog_diary_pro_is_event_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'blog_diary_pro_theme_options[event_title]', array(
		'selector'            => '#music-upcoming-events h2.music-section-title',
		'settings'            => 'blog_diary_pro_theme_options[event_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'blog_diary_pro_event_title_partial',
    ) );
}

// event subtitle setting and control
$wp_customize->add_setting( 'blog_diary_pro_theme_options[event_description]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['event_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'blog_diary_pro_theme_options[event_description]', array(
	'label'           	=> esc_html__( 'Description', 'blog-diary-pro' ),
	'section'        	=> 'blog_diary_pro_event_section',
	'active_callback' 	=> 'blog_diary_pro_is_event_section_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'blog_diary_pro_theme_options[event_description]', array(
		'selector'            => '#music-upcoming-events p.music-section-subtitle',
		'settings'            => 'blog_diary_pro_theme_options[event_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'blog_diary_pro_event_description_partial',
    ) );
}

// event readmore setting and control
$wp_customize->add_setting( 'blog_diary_pro_theme_options[event_readmore]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['event_readmore'],
) );

$wp_customize->add_control( 'blog_diary_pro_theme_options[event_readmore]', array(
	'label'           	=> esc_html__( 'Read More Label', 'blog-diary-pro' ),
	'section'        	=> 'blog_diary_pro_event_section',
	'active_callback' 	=> 'blog_diary_pro_is_event_section_enable',
	'type'				=> 'text',
) );

// Event content type control and setting
$wp_customize->add_setting( 'blog_diary_pro_theme_options[event_content_type]', array(
	'default'          	=> $options['event_content_type'],
	'sanitize_callback' => 'blog_diary_pro_sanitize_select',
) );

$wp_customize->add_control( 'blog_diary_pro_theme_options[event_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'blog-diary-pro' ),
	'section'           => 'blog_diary_pro_event_section',
	'type'				=> 'select',
	'active_callback' 	=> 'blog_diary_pro_is_event_section_enable',
	'choices'			=> blog_diary_pro_event_content_type(),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'blog_diary_pro_theme_options[event_count]', array(
	'default'          	=> $options['event_count'],
	'sanitize_callback' => 'blog_diary_pro_sanitize_number_range',
	'validate_callback' => 'blog_diary_pro_validate_event_count',
) );

$wp_customize->add_control( 'blog_diary_pro_theme_options[event_count]', array(
	'label'             => esc_html__( 'Number of Event', 'blog-diary-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'blog-diary-pro' ),
	'section'           => 'blog_diary_pro_event_section',
	'active_callback'   => 'blog_diary_pro_is_event_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['event_count']; $i++ ) :

	// event posts drop down chooser control and setting
	$wp_customize->add_setting( 'blog_diary_pro_theme_options[event_content_page_' . $i . ']', array(
		'sanitize_callback' => 'blog_diary_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Blog_Diary_Pro_Dropdown_Chooser( $wp_customize, 'blog_diary_pro_theme_options[event_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'blog-diary-pro' ), $i ),
		'section'           => 'blog_diary_pro_event_section',
		'choices'			=> blog_diary_pro_page_choices(),
		'active_callback'	=> 'blog_diary_pro_is_event_section_content_page_enable',
	) ) );

	// event posts drop down chooser control and setting
	$wp_customize->add_setting( 'blog_diary_pro_theme_options[event_content_post_' . $i . ']', array(
		'sanitize_callback' => 'blog_diary_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Blog_Diary_Pro_Dropdown_Chooser( $wp_customize, 'blog_diary_pro_theme_options[event_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'blog-diary-pro' ), $i ),
		'section'           => 'blog_diary_pro_event_section',
		'choices'			=> blog_diary_pro_post_choices(),
		'active_callback'	=> 'blog_diary_pro_is_event_section_content_post_enable',
	) ) );

	// event posts drop down chooser control and setting
	$wp_customize->add_setting( 'blog_diary_pro_theme_options[event_content_event_' . $i . ']', array(
		'sanitize_callback' => 'blog_diary_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Blog_Diary_Pro_Dropdown_Chooser( $wp_customize, 'blog_diary_pro_theme_options[event_content_event_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Event %d', 'blog-diary-pro' ), $i ),
		'section'           => 'blog_diary_pro_event_section',
		'choices'			=> blog_diary_pro_event_choices(),
		'active_callback'	=> 'blog_diary_pro_is_event_section_content_event_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'blog_diary_pro_theme_options[event_content_category]', array(
	'sanitize_callback' => 'blog_diary_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Blog_Diary_Pro_Dropdown_Taxonomies_Control( $wp_customize,'blog_diary_pro_theme_options[event_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'blog-diary-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'blog-diary-pro' ),
	'section'           => 'blog_diary_pro_event_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'blog_diary_pro_is_event_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'blog_diary_pro_theme_options[event_content_event_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Blog_Diary_Pro_Dropdown_Taxonomies_Control( $wp_customize,'blog_diary_pro_theme_options[event_content_event_category]', array(
	'label'             => esc_html__( 'Select Event Category', 'blog-diary-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'blog-diary-pro' ),
	'section'           => 'blog_diary_pro_event_section',
	'taxonomy'			=> 'tp-event-category',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'blog_diary_pro_is_event_section_content_event_category_enable'
) ) );

// event btn title setting and control
$wp_customize->add_setting( 'blog_diary_pro_theme_options[event_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['event_btn_title'],
) );

$wp_customize->add_control( 'blog_diary_pro_theme_options[event_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'blog-diary-pro' ),
	'section'        	=> 'blog_diary_pro_event_section',
	'active_callback' 	=> 'blog_diary_pro_is_event_section_enable',
	'type'				=> 'text',
) );

// event btn link setting and control
$wp_customize->add_setting( 'blog_diary_pro_theme_options[event_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'blog_diary_pro_theme_options[event_btn_link]', array(
	'label'           	=> esc_html__( 'Button Url', 'blog-diary-pro' ),
	'section'        	=> 'blog_diary_pro_event_section',
	'active_callback' 	=> 'blog_diary_pro_is_event_section_enable',
	'type'				=> 'url',
) );