<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Blog Diary Pro
 * @since Blog Diary Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function blog_diary_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'blog-diary-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function blog_diary_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'blog-diary-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of category for category choices.
 * @return Array Array of post ids and name.
 */
function blog_diary_pro_category_choices() {
    $tax_args = array(
        'hierarchical' => 0,
        'taxonomy'     => 'category',
    );
    $taxonomies = get_categories( $tax_args );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'blog-diary-pro' );
    foreach ( $taxonomies as $tax ) {
        $choices[ $tax->term_id ] = $tax->name;
    }
    return  $choices;
}

/**
 * List of products for post choices.
 * @return Array Array of post ids and name.
 */
function blog_diary_pro_product_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'product' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'blog-diary-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

if ( ! function_exists( 'blog_diary_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function blog_diary_pro_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'blog-diary-pro' ),
            'header-font-1'   => esc_html__( 'Rajdhani', 'blog-diary-pro' ),
            'header-font-2'   => esc_html__( 'Cherry Swash', 'blog-diary-pro' ),
            'header-font-3'   => esc_html__( 'Philosopher', 'blog-diary-pro' ),
            'header-font-4'   => esc_html__( 'Slabo 27px', 'blog-diary-pro' ),
            'header-font-5'   => esc_html__( 'Dosis', 'blog-diary-pro' ),
        );

        $output = apply_filters( 'blog_diary_pro_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;

/**
 * List of trips for post choices.
 * @return Array Array of post ids and name.
 */
function blog_diary_pro_trip_choices() {
    $posts = get_posts( array( 'post_type' => 'itineraries', 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'blog-diary-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    wp_reset_postdata();
    return  $choices;
}

/**
 * List of events for post choices.
 * @return Array Array of post ids and name.
 */
function blog_diary_pro_event_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'tp-event' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'blog-diary-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}


if ( ! function_exists( 'blog_diary_pro_body_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function blog_diary_pro_body_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'blog-diary-pro' ),
            'body-font-1'     => esc_html__( 'News Cycle', 'blog-diary-pro' ),
            'body-font-2'     => esc_html__( 'Pontano Sans', 'blog-diary-pro' ),
            'body-font-3'     => esc_html__( 'Gudea', 'blog-diary-pro' ),
            'body-font-4'     => esc_html__( 'Quattrocento', 'blog-diary-pro' ),
            'body-font-5'     => esc_html__( 'Khand', 'blog-diary-pro' ),
        );

        $output = apply_filters( 'blog_diary_pro_body_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'blog_diary_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function blog_diary_pro_site_layout() {
        $blog_diary_pro_site_layout = array(
            'wide'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout' => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'blog_diary_pro_site_layout', $blog_diary_pro_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'blog_diary_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function blog_diary_pro_selected_sidebar() {
        $blog_diary_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'blog-diary-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'blog-diary-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'blog-diary-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'blog-diary-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'blog-diary-pro' ),
        );

        $output = apply_filters( 'blog_diary_pro_selected_sidebar', $blog_diary_pro_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'blog_diary_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function blog_diary_pro_global_sidebar_position() {
        $blog_diary_pro_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'blog_diary_pro_global_sidebar_position', $blog_diary_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'blog_diary_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function blog_diary_pro_sidebar_position() {
        $blog_diary_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'   => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'blog_diary_pro_sidebar_position', $blog_diary_pro_sidebar_position );

        return $output;
    }
endif;

if ( ! function_exists( 'blog_diary_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function blog_diary_pro_pagination_options() {
        $blog_diary_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'blog-diary-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'blog-diary-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'blog-diary-pro' ),
        );

        $output = apply_filters( 'blog_diary_pro_pagination_options', $blog_diary_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'blog_diary_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function blog_diary_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'blog-diary-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'blog-diary-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'blog-diary-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'blog-diary-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'blog-diary-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'blog-diary-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'blog-diary-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'blog-diary-pro' ),
        );
        return apply_filters( 'blog_diary_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'blog_diary_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function blog_diary_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'blog-diary-pro' ),
            'off'       => esc_html__( 'Disable', 'blog-diary-pro' )
        );
        return apply_filters( 'blog_diary_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'blog_diary_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function blog_diary_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'blog-diary-pro' ),
            'off'       => esc_html__( 'No', 'blog-diary-pro' )
        );
        return apply_filters( 'blog_diary_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'blog_diary_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function blog_diary_pro_sortable_sections() {
        $sections = array(
            'slider'    => esc_html__( 'Slider', 'blog-diary-pro' ),
            'featured_slider' => esc_html__( 'Featured Slider', 'blog-diary-pro' ),
            'latest_posts'  => esc_html__( 'Latest Posts', 'blog-diary-pro' ),
            'must_read_posts' => esc_html__( 'Must Read Posts', 'blog-diary-pro' ),
            'blog'      => esc_html__( 'Blog', 'blog-diary-pro' ),
        );
        return apply_filters( 'blog_diary_pro_sortable_sections', $sections );
    }
endif;

if ( ! function_exists( 'blog_diary_pro_slider_content_type' ) ) :
    /**
     * Slider Options
     * @return array site slider options
     */
    function blog_diary_pro_slider_content_type() {
        $blog_diary_pro_slider_content_type = array(
            'page'      => esc_html__( 'Page', 'blog-diary-pro' ),
            'post'      => esc_html__( 'Post', 'blog-diary-pro' ),
            'category'  => esc_html__( 'Category', 'blog-diary-pro' ),
        );

        if ( class_exists( 'WooCommerce' ) ) {
            $blog_diary_pro_slider_content_type = array_merge( $blog_diary_pro_slider_content_type, array(
                'product'   => esc_html__( 'Product', 'blog-diary-pro' ),
                'product-category'   => esc_html__( 'Product Category', 'blog-diary-pro' ),
                ) );
        }

        $output = apply_filters( 'blog_diary_pro_slider_content_type', $blog_diary_pro_slider_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'blog_diary_pro_recent_product_options' ) ) :
    /**
     * List of recent_product options
     * @return array List of recent_product options.
     */
    function blog_diary_pro_recent_product_options() {
    
        if ( class_exists( 'WooCommerce' ) ) {
                $arr = array(
                'product'           => esc_html__( 'Product', 'blog-diary-pro' ),
                'product-cat'       => esc_html__( 'Product Category', 'blog-diary-pro' ),
            );
        }

        return apply_filters( 'blog_diary_pro_recent_product_options', $arr );
    }
endif;


if ( ! function_exists( 'blog_diary_pro_popular_destination_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function blog_diary_pro_popular_destination_content_type() {
        $blog_diary_pro_popular_destination_content_type = array(
            'page'      => esc_html__( 'Page', 'blog-diary-pro' ),
            'post'      => esc_html__( 'Post', 'blog-diary-pro' ),
            'category'  => esc_html__( 'Category', 'blog-diary-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $blog_diary_pro_popular_destination_content_type = array_merge( $blog_diary_pro_popular_destination_content_type, array(
                'trip'          => esc_html__( 'Trip', 'blog-diary-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'blog-diary-pro' ),
                'destination'   => esc_html__( 'Destination', 'blog-diary-pro' ),
                'activity'      => esc_html__( 'Activity', 'blog-diary-pro' ),
                ) );
        }

        $output = apply_filters( 'blog_diary_pro_popular_destination_content_type', $blog_diary_pro_popular_destination_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'blog_diary_pro_popular_tours_content_type' ) ) :
    /**
     * Tours Options
     * @return array site gallery options
     */
    function blog_diary_pro_popular_tours_content_type() {
        $blog_diary_pro_popular_tours_content_type = array(
            'page'      => esc_html__( 'Page', 'blog-diary-pro' ),
            'post'      => esc_html__( 'Post', 'blog-diary-pro' ),
            'category'  => esc_html__( 'Category', 'blog-diary-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $blog_diary_pro_popular_tours_content_type = array_merge( $blog_diary_pro_popular_tours_content_type, array(
                'trip'          => esc_html__( 'Trip', 'blog-diary-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'blog-diary-pro' ),
                'tours'         => esc_html__( 'Tours', 'blog-diary-pro' ),
                'activity'      => esc_html__( 'Activity', 'blog-diary-pro' ),
                ) );
        }

        $output = apply_filters( 'blog_diary_pro_popular_tours_content_type', $blog_diary_pro_popular_tours_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'blog_diary_pro_event_content_type' ) ) :
    /**
     * Special Offer Options
     * @return array site event options
     */
    function blog_diary_pro_event_content_type() {
        $blog_diary_pro_event_content_type = array(
            'page'      => esc_html__( 'Page', 'blog-diary-pro' ),
            'post'      => esc_html__( 'Post', 'blog-diary-pro' ),
            'category'  => esc_html__( 'Category', 'blog-diary-pro' ),
        );

        if ( class_exists( 'TP_Education' ) ) {
            $blog_diary_pro_event_content_type = array_merge( $blog_diary_pro_event_content_type, array(
                'event'   => esc_html__( 'Event', 'blog-diary-pro' ),
                'event-category'   => esc_html__( 'Event Category', 'blog-diary-pro' ),
                ) );
        }

        $output = apply_filters( 'blog_diary_pro_event_content_type', $blog_diary_pro_event_content_type );


        return $output;
    }
endif;