<?php
/**
 * Blog section
 *
 * This is the template for the content of blog section
 *
 * @package Theme Palace
 * @subpackage Blog Diary Pro
 * @since Blog Diary Pro 1.0.0
 */
if ( ! function_exists( 'blog_diary_pro_add_blog_section' ) ) :
    /**
    * Add blog section
    *
    *@since Blog Diary Pro 1.0.0
    */
    function blog_diary_pro_add_blog_section() {
        $options = blog_diary_pro_get_theme_options();
        // Check if blog is enabled on frontpage
        $blog_enable = apply_filters( 'blog_diary_pro_section_status', true, 'blog_section_enable' );

        if ( true !== $blog_enable ) {
            return false;
        }
        // Get blog section details
        $section_details = array();
        $section_details = apply_filters( 'blog_diary_pro_filter_blog_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render blog section now.
        blog_diary_pro_render_blog_section( $section_details );
    }
endif;

if ( ! function_exists( 'blog_diary_pro_get_blog_section_details' ) ) :
    /**
    * blog section details.
    *
    * @since Blog Diary Pro 1.0.0
    * @param array $input blog section details.
    */
    function blog_diary_pro_get_blog_section_details( $input ) {
        $options = blog_diary_pro_get_theme_options();

        // Content type.
        $blog_content_type  = $options['blog_content_type'];
        $blog_count = ! empty( $options['blog_count'] ) ? $options['blog_count'] : 4;
        
        $content = array();
        switch ( $blog_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $blog_count; $i++ ) {
                    if ( ! empty( $options['blog_content_page_' . $i] ) )
                        $page_ids[] = $options['blog_content_page_' . $i];
                }
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $blog_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $blog_count; $i++ ) {
                    if ( ! empty( $options['blog_content_post_' . $i] ) )
                        $post_ids[] = $options['blog_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $blog_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['blog_content_category'] ) ? $options['blog_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $blog_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['blog_category_exclude'] ) ? $options['blog_category_exclude'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $blog_count ),
                    'category__not_in'  => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['author']    = blog_diary_pro_author();
                $page_post['excerpt']   = blog_diary_pro_trim_content( 20 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// blog section content details.
add_filter( 'blog_diary_pro_filter_blog_section_details', 'blog_diary_pro_get_blog_section_details' );


if ( ! function_exists( 'blog_diary_pro_render_blog_section' ) ) :
  /**
   * Start blog section
   *
   * @return string blog content
   * @since Blog Diary Pro 1.0.0
   *
   */
   function blog_diary_pro_render_blog_section( $content_details = array() ) {
        $options = blog_diary_pro_get_theme_options();
        $blog_content_type  = $options['blog_content_type'];
        $readmore = ! empty( $options['blog_btn_title'] ) ? $options['blog_btn_title'] : esc_html__( 'Read More', 'blog-diary-pro' );

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <?php if ( $options['home_layout'] == 'default-design' || $options['home_layout'] == 'second-design' || $options['home_layout'] == 'fourth-design' ): ?>

        <?php if( $options['home_layout'] == 'fourth-design' && !empty( $options['ads_image'] ) && !empty( $options['ads_url'] ) ): ?>
            
            <div id="advertisement-section">
                <a href="<?php echo esc_url( $options['ads_url'] ); ?>"><img src="<?php echo esc_url( $options['ads_image'] ); ?>" alt="<?php esc_attr_e('site-advertisement', 'blog-diary-pro'); ?>"></a>
            </div><!-- #advertisement-section -->
        <?php endif; ?>

        <div id="blog" class="page-section">
            <div class="archive-blog-wrapper">
                <?php if ( ! empty( $options['blog_title'] ) ) : ?>
                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html( $options['blog_title'] ); ?></h2>
                    </div><!-- .section-header -->
                <?php endif; ?>

                <div class="section-content">
                    <?php foreach ( $content_details as $content ) : ?>
                        <article class="<?php echo ! empty( $content['image'] ) ? 'has' : 'no'; ?>-post-thumbnail">
                            <div class="post-wrapper">
                                <?php if ( ! empty( $content['image'] ) ) : ?>
                                    <div class="featured-image" style="background-image:url('<?php echo esc_url( $content['image'] ); ?>');">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                    </div><!-- .featured-image-->
                                <?php endif; ?>

                               <div class="entry-container">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <div class="entry-meta">
                                       <?php 
                                        echo wp_kses_post( $content['author'] );
                                        blog_diary_pro_posted_on( $content['id'] ); ?>
                                        <?php if ( 'page' !== $blog_content_type ) : ?>
                                            <span class="cat-links">
                                                <?php the_category( '', '', $content['id'] ); ?>
                                            </span><!-- .cat-links --> 
                                        <?php endif; ?> 
                                    </div><!-- .entry-meta -->

                                    <div class="entry-content">
                                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                    </div>
                                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn">
                                            <span class="screen-reader-text"><?php echo esc_html( $content['title'] ); ?></span>
                                            <?php echo esc_html( $readmore );  ?>
                                        </a>
                                </div><!-- .entry-container -->
                            </div>
                        </article>
                    <?php  endforeach;  ?>
                </div><!-- .section-content -->
            </div><!-- .archive-wrapper -->
        </div><!-- #blog -->

    <?php endif; ?>

    <?php if ( $options['home_layout'] == 'third-design' || $options['home_layout'] == 'fifth-design' || $options['home_layout'] == 'seventh-design' ): ?>

         <div id="business-latest-posts" class="relative page-section">
                <div class="wrapper">
                    <div class="business-section-header">
                    <?php if ( ! empty( $options['blog_title'] ) ) : ?>
                        <h2 class="business-section-title"><?php echo esc_html( $options['blog_title'] ); ?></h2>
                    <?php endif; ?>

                    <?php if ( ! empty( $options['blog_description'] ) ) : ?>
                        <p class="business-section-subtitle"><?php echo esc_html( $options['blog_description'] ); ?></p>
                    <?php endif; ?>
                    </div><!-- .business-section-header -->

                    <div class="business-section-content clear col-3">
                        
                    <?php foreach ( $content_details as $content ) : ?>
                        <article class="<?php echo ! empty( $content['image'] ) ? 'has' : 'no'; ?>-post-thumbnail">
                            <div class="business-post-item">
                            <?php if ( ! empty( $content['image'] ) ) : ?>
                                <div class="featured-image">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" alt="<?php echo esc_html( $content['title'] ); ?>"></a>
                                </div><!-- .featured-image -->
                            <?php endif; ?>

                                <div class="entry-container">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <div class="entry-content"><?php echo esc_html( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-content -->

                                    <div class="entry-meta clear">
                                        <?php blog_diary_pro_posted_on( $content['id'] );  ?>

                                        
                                        <span class="more-link"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $readmore );  ?></a></span>
                                    </div><!-- .entry-meta -->
                                </div><!-- .entry-container -->
                            </div><!-- .business-post-item -->
                        </article>
                    <?php endforeach; ?>

                    </div><!-- .business-section-content -->
                </div><!-- .wrapper -->
            </div>

    <?php endif ?>

    <?php if ( $options['home_layout'] == 'sixth-design' ): ?>

        <div id="travel-blog" class="blog-posts-wrapper page-section relative">
            <div class="section-header">

            <?php if ( ! empty( $options['blog_title'] ) ) : ?>
                <h2 class="section-title"><?php echo esc_html( $options['blog_title'] ); ?></h2>
            <?php endif; ?>

            <?php if( !empty( $options['blog_btn_url'] ) && $options['blog_btn_title'] ): ?>
                <div class="view-all">
                    <a href="<?php echo esc_url( $options['blog_btn_url'] ); ?>" class="view-all" target="_blank"><?php echo esc_html( $options['blog_btn_title'] ); ?><i class="fa fa-long-arrow-right"></i></a>
                </div><!-- .view-all -->
            <?php endif; ?>
            </div><!-- .section-header -->

            <div class="section-content col-3 clear">

            <?php foreach ( $content_details as $content ) : ?>

                <article class="<?php echo ! empty( $content['image'] ) ? 'has' : 'no'; ?>-post-thumbnail">
                    <div class="post-item">
                    <?php if ( ! empty( $content['image'] ) ) : ?>
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                        </div><!-- .featured-image -->
                    <?php endif ?>

                        <div class="blog-overlay"></div>

                        <div class="entry-container">
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>

                            <div class="entry-meta">                 
                                <span class="date"><?php blog_diary_pro_posted_on( $content['id'] ); ?></span>                           
                            </div><!-- .entry-meta -->
                        </div><!-- .entry-container -->
                    </div><!-- .post-item -->
                </article>

            <?php endforeach; ?>

            </div><!-- .section-content -->
        </div>

    <?php endif; ?>

    <?php }
endif;

