<?php
/**
 * Counter section
 *
 * This is the template for the content of counter section
 *
 * @package Theme Palace
 * @subpackage Blog Diary Pro
 * @since Blog Diary Pro 1.0.0
 */
if ( ! function_exists( 'blog_diary_pro_add_counter_section' ) ) :
    /**
    * Add counter section
    *
    *@since Blog Diary Pro 1.0.0
    */
    function blog_diary_pro_add_counter_section() {
    	$options = blog_diary_pro_get_theme_options();
        // Check if counter is enabled on frontpage
        $counter_enable = apply_filters( 'blog_diary_pro_section_status', true, 'counter_section_enable' );

        if ( true !== $counter_enable ) {
            return false;
        }

        // Render counter section now.
        blog_diary_pro_render_counter_section();
    }
endif;

if ( ! function_exists( 'blog_diary_pro_render_counter_section' ) ) :
  /**
   * Start counter section
   *
   * @return string counter content
   * @since Blog Diary Pro 1.0.0
   *
   */
   function blog_diary_pro_render_counter_section() {
        $options = blog_diary_pro_get_theme_options();
        $image = ! empty( $options['counter_image'] ) ? $options['counter_image'] : '';
                
        $col = 0;
        for ( $i = 1; $i <= 4 ; $i++) { 
            if ( ! empty( $options['counter_value_' . $i] ) && ! empty( $options['counter_label_' . $i] ) ) : 
                $col++;
            endif; 
        } 

        if ( 0 === $col ) {
            return;
        }
        ?>

        <div id="business-counter" class="relative page-section" style="background-image: url('<?php echo esc_url( $image ); ?>');">
                <div class="overlay"></div>
                <div class="wrapper">
                    <div class="business-section-content clear col-4">
                       <?php for ( $i = 1; $i <= 4 ; $i++) { 
                        if ( ! empty( $options['counter_value_' . $i] ) && ! empty( $options['counter_label_' . $i] ) ) : ?>
                        <article>
                            <header class="entry-header">
                                <div class="counter-icon">
                                   <i class="fa <?php echo esc_attr( $options['counter_icon_' . $i] ); ?>"></i>
                                </div><!-- .counter-icon -->

                                <h3 class="counter-value"><?php echo esc_html( $options['counter_value_' . $i] ); ?></h3>
                                <div class="separator-line"></div>
                                <h2 class="entry-title"><?php echo esc_html( $options['counter_label_' . $i] ); ?></h2>
                            </header>
                        </article>
                        <?php endif; 
                    } ?>
                    </div><!-- .business-section-content -->
                </div><!-- .wrapper -->
            </div>
            
    <?php }
endif;