<?php
/**
 * event section
 *
 * This is the template for the content of event section
 *
 * @package Theme Palace
 * @subpackage Blog Diary Pro
 * @since Blog Diary Pro 1.0.0
 */
if ( ! function_exists( 'blog_diary_pro_add_event_section' ) ) :
    /**
    * Add event section
    *
    *@since Blog Diary Pro 1.0.0
    */
    function blog_diary_pro_add_event_section() {
    	$options = blog_diary_pro_get_theme_options();
        // Check if event is enabled on frontpage
        $event_enable = apply_filters( 'blog_diary_pro_section_status', true, 'event_section_enable' );

        if ( true !== $event_enable ) {
            return false;
        }
        // Get event section details
        $section_details = array();
        $section_details = apply_filters( 'blog_diary_pro_filter_event_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render event section now.
        blog_diary_pro_render_event_section( $section_details );
    }
endif;

if ( ! function_exists( 'blog_diary_pro_get_event_section_details' ) ) :
    /**
    * event section details.
    *
    * @since Blog Diary Pro 1.0.0
    * @param array $input event section details.
    */
    function blog_diary_pro_get_event_section_details( $input ) {
        $options = blog_diary_pro_get_theme_options();

        // Content type.
        $event_content_type  = $options['event_content_type'];
        $event_count = ! empty( $options['event_count'] ) ? $options['event_count'] : 3;

        $content = array();
        switch ( $event_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $event_count; $i++ ) {
                    if ( ! empty( $options['event_content_page_' . $i] ) )
                        $page_ids[] = $options['event_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $event_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $event_count; $i++ ) {
                    if ( ! empty( $options['event_content_post_' . $i] ) )
                        $post_ids[] = $options['event_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $event_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['event_content_category'] ) ? $options['event_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $event_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'event':
                $page_ids = array();

                for ( $i = 1; $i <= $event_count; $i++ ) {
                    if ( ! empty( $options['event_content_event_' . $i] ) )
                        $page_ids[] = $options['event_content_event_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'tp-event',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $event_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'event-category':
                $cat_id = ! empty( $options['event_content_event_category'] ) ? $options['event_content_event_category'] : '';
                $args = array(
                    'post_type'      => 'tp-event',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'tp-event-category',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $event_count ),
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = blog_diary_pro_trim_content( 5 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), array( 60, 60 ) ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-150x150.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// event section content details.
add_filter( 'blog_diary_pro_filter_event_section_details', 'blog_diary_pro_get_event_section_details' );


if ( ! function_exists( 'blog_diary_pro_render_event_section' ) ) :
  /**
   * Start event section
   *
   * @return string event content
   * @since Blog Diary Pro 1.0.0
   *
   */
   function blog_diary_pro_render_event_section( $content_details = array() ) {
        $options = blog_diary_pro_get_theme_options();
        $event_content_type  = $options['event_content_type'];
        $readmore = ! empty( $options['event_readmore'] ) ? $options['event_readmore'] : esc_html__( 'Buy Ticket', 'blog-diary-pro' );

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="music-upcoming-events" class="relative page-section">
                <div class="wrapper">
                    <div class="music-section-header">
                    <?php if ( ! empty( $options['event_title'] ) ) : ?>
                        <h2 class="music-section-title"><?php echo esc_html( $options['event_title'] ); ?></h2>
                    <?php endif; ?>

                    <?php if ( ! empty( $options['event_description'] ) ) : ?>
                        <p class="music-section-subtitle"><?php echo wp_kses_post( $options['event_description'] ); ?></p>
                    <?php endif; ?>
                    </div><!-- .business-section-header -->

                    <div class="music-section-content">

                        <?php foreach ( $content_details as $content ) : 
                        if ( in_array( $event_content_type, array( 'event', 'event-category' ) ) && class_exists( 'TP_Education' ) ) :
                        $event_date = get_tp_event_date( $content['id'] );
                        $event_location = get_tp_event_location( $content['id'] );
                        $event_time = get_tp_event_start_time( $content['id'] );
                        endif;
                        ?>
                        
                        <article>
                        <?php if ( in_array( $event_content_type, array( 'event', 'event-category' ) ) && ! empty( $event_date ) ) : ?>
                            <h4 class="event-date"><?php tp_event_date( $content['id'] ); ?></h4>
                        <?php endif; ?>
                            <header class="entry-header">
                            <?php if( !empty( $content['image'] ) ): ?>
                                <img src="<?php echo esc_url( $content['image'] ); ?>" alt="<?php echo esc_html( $content['title'] ); ?>">
                            <?php endif; ?>
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                <?php if ( in_array( $event_content_type, array( 'event', 'event-category' ) ) && ! empty( $event_location ) ) : ?>
                                    <p class="location"><?php tp_event_location( $content['id'] ); ?></p>
                                <?php endif; ?>
                            </header>

                            <?php if ( in_array( $event_content_type, array( 'event', 'event-category' ) ) && ! empty( $event_time ) ) : ?>
                            <span class="event-time">
                               <i class="fa fa-clock-o"></i>
                               <?php tp_event_start_time( $content['id'] ); ?>
                            </span>
                        <?php endif; ?>
                            <span class="buy-ticket">
                                <div class="music-read-more">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $readmore ); ?></a>
                                </div>
                            </span>
                        </article>

                        <?php endforeach; ?>

                    </div><!-- .section-content -->
                    <?php if ( ! empty( $options['event_btn_title'] ) && ! empty( $options['event_btn_link'] ) ) : ?>
                    <div class="music-read-more">
                        <a href="<?php echo esc_url( $options['event_btn_link'] ); ?>"><?php echo esc_html( $options['event_btn_title'] ); ?></a>
                    </div>
                <?php endif; ?>
                </div><!-- .wrapper -->
            </div>

    <?php }
endif;