<?php
/**
 * release section
 *
 * This is the template for the content of release section
 *
 * @package Theme Palace
 * @subpackage Blog Diary Pro
 * @since Blog Diary Pro 1.0.0
 */
if ( ! function_exists( 'blog_diary_pro_add_release_section' ) ) :
    /**
    * Add release section
    *
    *@since Blog Diary Pro 1.0.0
    */
    function blog_diary_pro_add_release_section() {
        $options = blog_diary_pro_get_theme_options();
        // Check if release is enabled on frontpage
        $release_enable = apply_filters( 'blog_diary_pro_section_status', true, 'release_section_enable' );

        if ( true !== $release_enable ) {
            return false;
        }
        // Get release section details
        $section_details = array();
        $section_details = apply_filters( 'blog_diary_pro_filter_release_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render release section now.
        blog_diary_pro_render_release_section( $section_details );
    }
endif;

if ( ! function_exists( 'blog_diary_pro_get_release_section_details' ) ) :
    /**
    * release section details.
    *
    * @since Blog Diary Pro 1.0.0
    * @param array $input release section details.
    */
    function blog_diary_pro_get_release_section_details( $input ) {
        $options = blog_diary_pro_get_theme_options();

        // Content type.
        $release_content_type  = $options['release_content_type'];
        $release_count = ! empty( $options['release_count'] ) ? $options['release_count'] : 3;
        
        $content = array();
        switch ( $release_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $release_count; $i++ ) {
                    if ( ! empty( $options['release_content_page_' . $i] ) )
                        $page_ids[] = $options['release_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $release_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $release_count; $i++ ) {
                    if ( ! empty( $options['release_content_post_' . $i] ) )
                        $post_ids[] = $options['release_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $release_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['release_content_category'] ) ? $options['release_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $release_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// release section content details.
add_filter( 'blog_diary_pro_filter_release_section_details', 'blog_diary_pro_get_release_section_details' );


if ( ! function_exists( 'blog_diary_pro_render_release_section' ) ) :
  /**
   * Start release section
   *
   * @return string release content
   * @since Blog Diary Pro 1.0.0
   *
   */
   function blog_diary_pro_render_release_section( $content_details = array() ) {
        $options = blog_diary_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="music-album" class="page-section">
                <div class="wrapper">
                    <div class="music-section-header">
                    <?php if( !empty( $options['release_title'] ) ): ?>
                        <h2 class="music-section-title"><?php echo esc_html( $options['release_title'] ); ?></h2>
                    <?php endif; ?>
                    <?php if( !empty( $options['release_description'] ) ): ?>
                        <p class="music-section-subtitle"><?php echo wp_kses_post( $options['release_description'] ); ?></p>
                    <?php endif; ?>
                    </div><!-- .music-section-header -->

                    <div class="music-wrapper col-3 clear">
                        <?php foreach ($content_details as $content): ?>

                        <article class="hentry">
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ) ?>');">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ) ?>"><?php echo esc_html( $content['title'] ) ?></a></h2>
                                </header>
                            </div>
                        </article>

                        <?php endforeach ?>
                    </div><!-- .release-wrapper -->

                    <?php if ( !empty( $options['release_btn_title'] ) && !empty( $options['release_btn_url'] ) ): ?>
                    <div class="music-read-more">
                        <a href="<?php echo esc_url( $options['release_btn_url'] ) ?>"><?php echo esc_html( $options['release_btn_title'] ) ?></a>
                    </div>
                <?php endif; ?>
                </div><!-- .wrapper -->
            </div>
    <?php }
endif;