<?php
/**
 * Testimonial section
 *
 * This is the template for the content of testimonial section
 *
 * @package Theme Palace
 * @subpackage Blog Diary Pro
 * @since Blog Diary Pro 1.0.0
 */
if ( ! function_exists( 'blog_diary_pro_add_testimonial_section' ) ) :
    /**
    * Add testimonial section
    *
    *@since Blog Diary Pro 1.0.0
    */
    function blog_diary_pro_add_testimonial_section() {
        $options = blog_diary_pro_get_theme_options();
        // Check if testimonial is enabled on frontpage
        $testimonial_enable = apply_filters( 'blog_diary_pro_section_status', true, 'testimonial_section_enable' );

        if ( true !== $testimonial_enable ) {
            return false;
        }
        // Get testimonial section details
        $section_details = array();
        $section_details = apply_filters( 'blog_diary_pro_filter_testimonial_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render testimonial section now.
        blog_diary_pro_render_testimonial_section( $section_details );
    }
endif;

if ( ! function_exists( 'blog_diary_pro_get_testimonial_section_details' ) ) :
    /**
    * testimonial section details.
    *
    * @since Blog Diary Pro 1.0.0
    * @param array $input testimonial section details.
    */
    function blog_diary_pro_get_testimonial_section_details( $input ) {
        $options = blog_diary_pro_get_theme_options();

        // Content type.
        $testimonial_content_type   = $options['testimonial_content_type'];
        $testimonial_count          = ! empty( $options['testimonial_count'] ) ? $options['testimonial_count'] : 3;
        $content = array();
        switch ( $testimonial_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_page_' . $i] ) ) :
                        $page_ids[] = $options['testimonial_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $testimonial_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_post_' . $i] ) ) :
                        $post_ids[] = $options['testimonial_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $testimonial_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['testimonial_content_category'] ) ? $options['testimonial_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $testimonial_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }
        $query = new WP_Query( $args );
        $i = 1;
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = blog_diary_pro_trim_content( 30 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'thumbnail' ) : '';
                $page_post['position']  = ! empty( $options['testimonial_position_' . $i] ) ? $options['testimonial_position_' . $i] : '';

                // Push to the main array.
                array_push( $content, $page_post );
                $i++;
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// testimonial section content details.
add_filter( 'blog_diary_pro_filter_testimonial_section_details', 'blog_diary_pro_get_testimonial_section_details' );


if ( ! function_exists( 'blog_diary_pro_render_testimonial_section' ) ) :
  /**
   * Start testimonial section
   *
   * @return string testimonial content
   * @since Blog Diary Pro 1.0.0
   *
   */
   function blog_diary_pro_render_testimonial_section( $content_details = array() ) {
        $options = blog_diary_pro_get_theme_options();

        
        if ( empty( $content_details ) ) {
            return;
        } ?>
        <?php if ( $options['home_layout'] == 'sixth-design'): ?>
            
            <div id="testimonial" class="page-section relative">
                <?php if(!empty( $options['testimonial_title'] ) ): ?>
                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html( $options['testimonial_title'] ); ?></h2>
                    </div><!-- .section-header -->
                <?php endif; ?>

                <div class="testimonial-slider-wrapper" data-slick='{"slidesToShow": 3, "slidesToScroll": 1, "infinite": true, "speed": 1500, "dots": false, "arrows":false, "autoplay": false, "draggable": true, "fade": false }'>

                    <?php foreach ($content_details as $content): ?>

                        <article>
                            <div class="review-quote">“</div>
                            <div class="entry-content">
                                <p><?php echo wp_kses_post( $content['excerpt']); ?></p>
                            </div><!-- .entry-content -->

                            <div class="author-details">
                            <?php if(!empty( $content['image'] ) ): ?>
                                <div class="featured-image">
                                    <a href="<?php echo esc_url($content['url']); ?>"><img src="<?php echo esc_url($content['image']); ?>"></a>
                                </div><!-- .featured-image -->
                            <?php endif; ?>
                                
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>

                                    <span class="position"><?php echo esc_html( $content['position'] ); ?></span>
                                </header>
                            </div><!-- .author-details -->
                        </article>

                    <?php endforeach; ?>
                </div><!-- .testimonial-slider-wrapper -->
            </div>

        <?php endif ?>

             

    <?php }
endif;
            